@@ -10,4 +10,6 @@
 # Author: Alec Thomas <alec@swapoff.org>
 # Maintainers: Jean-Tiare Le Bigot <jtlebigot@socialludia.com>,
 
-from .onctuous import *
+from .schema import *
+from .errors import *
+from .validators import *
